==> google-cloud-service-management-1.2.2.tar.gz: google-cloud-service-management-1.2.2/google/cloud/servicemanagement_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.service_manager import ServiceManagerAsyncClient, ServiceManagerClient
from .types.resources import (
    ChangeReport,
    ConfigFile,
    ConfigRef,
    ConfigSource,
    Diagnostic,
    ManagedService,
    OperationMetadata,
    Rollout,
)
from .types.servicemanager import (
    CreateServiceConfigRequest,
    CreateServiceRequest,
    CreateServiceRolloutRequest,
    DeleteServiceRequest,
    GenerateConfigReportRequest,
    GenerateConfigReportResponse,
    GetServiceConfigRequest,
    GetServiceRequest,
    GetServiceRolloutRequest,
    ListServiceConfigsRequest,
    ListServiceConfigsResponse,
    ListServiceRolloutsRequest,
    ListServiceRolloutsResponse,
    ListServicesRequest,
    ListServicesResponse,
    SubmitConfigSourceRequest,
    SubmitConfigSourceResponse,
    UndeleteServiceRequest,
    UndeleteServiceResponse,
)

__all__ = (
    "ServiceManagerAsyncClient",
    "ChangeReport",
    "ConfigFile",
    "ConfigRef",
    "ConfigSource",
    "CreateServiceConfigRequest",
    "CreateServiceRequest",
    "CreateServiceRolloutRequest",
    "DeleteServiceRequest",
    "Diagnostic",
    "GenerateConfigReportRequest",
    "GenerateConfigReportResponse",
    "GetServiceConfigRequest",
    "GetServiceRequest",
    "GetServiceRolloutRequest",
    "ListServiceConfigsRequest",
    "ListServiceConfigsResponse",
    "ListServiceRolloutsRequest",
    "ListServiceRolloutsResponse",
    "ListServicesRequest",
    "ListServicesResponse",
    "ManagedService",
    "OperationMetadata",
    "Rollout",
    "ServiceManagerClient",
    "SubmitConfigSourceRequest",
    "SubmitConfigSourceResponse",
    "UndeleteServiceRequest",
    "UndeleteServiceResponse",
)

==> google-cloud-service-management-1.5.0.tar.gz: google-cloud-service-management-1.5.0/google/cloud/servicemanagement_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.servicemanagement import gapic_version as package_version

__version__ = package_version.__version__


from .services.service_manager import ServiceManagerAsyncClient, ServiceManagerClient
from .types.resources import (
    ChangeReport,
    ConfigFile,
    ConfigRef,
    ConfigSource,
    Diagnostic,
    ManagedService,
    OperationMetadata,
    Rollout,
)
from .types.servicemanager import (
    CreateServiceConfigRequest,
    CreateServiceRequest,
    CreateServiceRolloutRequest,
    DeleteServiceRequest,
    GenerateConfigReportRequest,
    GenerateConfigReportResponse,
    GetServiceConfigRequest,
    GetServiceRequest,
    GetServiceRolloutRequest,
    ListServiceConfigsRequest,
    ListServiceConfigsResponse,
    ListServiceRolloutsRequest,
    ListServiceRolloutsResponse,
    ListServicesRequest,
    ListServicesResponse,
    SubmitConfigSourceRequest,
    SubmitConfigSourceResponse,
    UndeleteServiceRequest,
    UndeleteServiceResponse,
)

__all__ = (
    "ServiceManagerAsyncClient",
    "ChangeReport",
    "ConfigFile",
    "ConfigRef",
    "ConfigSource",
    "CreateServiceConfigRequest",
    "CreateServiceRequest",
    "CreateServiceRolloutRequest",
    "DeleteServiceRequest",
    "Diagnostic",
    "GenerateConfigReportRequest",
    "GenerateConfigReportResponse",
    "GetServiceConfigRequest",
    "GetServiceRequest",
    "GetServiceRolloutRequest",
    "ListServiceConfigsRequest",
    "ListServiceConfigsResponse",
    "ListServiceRolloutsRequest",
    "ListServiceRolloutsResponse",
    "ListServicesRequest",
    "ListServicesResponse",
    "ManagedService",
    "OperationMetadata",
    "Rollout",
    "ServiceManagerClient",
    "SubmitConfigSourceRequest",
    "SubmitConfigSourceResponse",
    "UndeleteServiceRequest",
    "UndeleteServiceResponse",
)
